@@ -51,17 +51,17 @@ _coach_url = (
     'mp4:u/nfl/nfl/coachtapes/%s/%s_all_1600',
 )
 _broadcast_url = 'http://nlds82.cdnl3nl.neulion.com/nlds_vod/nfl/vod/' \
-                 '%s/%s/%s/%s/2_%s_%s_%s_%s_h_whole_%d_%s.mp4.m3u8'
+                 '%s/%s/%s/%s/%d_%s_%s_%s_%s_h_%s_%d_%s.mp4.m3u8'
 
 
 def _eprint(s):
     print >> sys.stderr, s
 
 
-def broadcast_urls(gobj, quality='1600'):
+def broadcast_urls(gobj, quality='1600', condensed=False):
     """
     Returns possible HTTP Live Stream URLs (an m3u8 file) for the given
-    game and quality. Use `nflvid.broadcast_url_status` to determine
+    game and quality. Use `nflvid.url_status` to determine
     if it's a valid URL or not. Alternatively, use
     `nflvid.first_valid_broadcast_url` to retrieve the first valid URL.
 
@@ -72,20 +72,29 @@ def broadcast_urls(gobj, quality='1600'):
     Note that it is unlikely any URL returned will be valid for
     preseason or postseason games.
     """
-    month, day = gobj.eid[4:6], gobj.eid[6:8]
+    year, month, day = gobj.eid[0:4], gobj.eid[4:6], gobj.eid[6:8]
+    if gobj.schedule['season_type'] == 'POST':
+        stype = 3
+    elif gobj.schedule['season_type'] == 'PRE':
+        stype = 1
+    else:
+        stype = 2
+
+    kind = 'snap2w' if condensed else 'whole'
     return [
         _broadcast_url
-        % (gobj.season(), month, day, gobj.gamekey, gobj.gamekey,
-           gobj.away.lower(), gobj.home.lower(), gobj.season(), i, quality)
+        % (year, month, day, gobj.gamekey, stype, gobj.gamekey,
+           gobj.away.lower(), gobj.home.lower(), gobj.season(), kind,
+           i, quality)
         for i in range(1, 4)
     ]
 
 
-def broadcast_url_status(url):
+def url_status(url):
     """
-    Returns the HTTP status as a string for the given broadcast URL. A
-    broadcast URL should be considered valid if and only if its HTTP
-    status is `200`.
+    Returns the HTTP status as a string for the given URL. A broadcast
+    URL should be considered valid if and only if its HTTP status is
+    `200`.
     """
     resp, _ = httplib2.Http().request(url, 'HEAD')
     return resp['status']
@@ -97,7 +106,7 @@ def first_valid_broadcast_url(urls):
     valid broadcast URL, then `None` is returned.
     """
     for url in urls:
-        if broadcast_url_status(url) == '200':
+        if url_status(url) == '200':
             return url
     return None
 
@@ -373,7 +382,8 @@ def artificial_slice(footage_play_dir, gobj, gobj_play):
         _run_command(cmd)
 
 
-def download_broadcast(footage_dir, gobj, quality='1600', dry_run=False):
+def download_broadcast(footage_dir, gobj, quality='1600', dry_run=False,
+                       condensed=False):
     """
     Starts an `ffmpeg` process to download the full broadcast of the
     given game with the quality provided. The qualities available are:
@@ -388,12 +398,19 @@ def download_broadcast(footage_dir, gobj, quality='1600', dry_run=False):
 
     A full game's worth of broadcast footage at a quality of 1600 is
     about **2GB**.
+
+    If `dry_run` is `True`, then only the first 30 seconds of the game
+    will be downloaded. Use this to quickly make sure everything is
+    working correctly.
+
+    If `condensed` is `True`, then a small recap of the game will be
+    downloaded instead.
     """
     fp = _full_path(footage_dir, gobj.eid)
     if os.access(fp, os.R_OK):
         raise LookupError('Footage path "%s" already exists.' % fp)
 
-    urls = broadcast_urls(gobj, quality)
+    urls = broadcast_urls(gobj, quality, condensed=condensed)
     url = first_valid_broadcast_url(urls)
     if url is None:
         _eprint('BAD URLs for game %s: %s'
